public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
From: Ingo Molnar <mingo@kernel.org>
To: linux-kernel@vger.kernel.org
Cc: Thomas Gleixner <tglx@linutronix.de>,
	Frederic Weisbecker <frederic@kernel.org>,
	"H . Peter Anvin" <hpa@zytor.com>,
	Linus Torvalds <torvalds@linux-foundation.org>,
	Peter Zijlstra <peterz@infradead.org>,
	Ingo Molnar <mingo@kernel.org>
Subject: [PATCH 04/17] treewide, timers: Rename add_timer_local() => timer_add_local()
Date: Mon, 14 Apr 2025 12:22:38 +0200	[thread overview]
Message-ID: <20250414102301.332225-5-mingo@kernel.org> (raw)
In-Reply-To: <20250414102301.332225-1-mingo@kernel.org>

Move this API to the canonical timer_*() namespace.

Signed-off-by: Ingo Molnar <mingo@kernel.org>
---
 include/linux/timer.h | 2 +-
 kernel/time/timer.c   | 6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/include/linux/timer.h b/include/linux/timer.h
index d35d3f27a987..5944cfb196c5 100644
--- a/include/linux/timer.h
+++ b/include/linux/timer.h
@@ -159,7 +159,7 @@ extern int timer_reduce(struct timer_list *timer, unsigned long expires);
 #define NEXT_TIMER_MAX_DELTA	((1UL << 30) - 1)
 
 extern void add_timer(struct timer_list *timer);
-extern void add_timer_local(struct timer_list *timer);
+extern void timer_add_local(struct timer_list *timer);
 extern void timer_add_global(struct timer_list *timer);
 
 extern int try_to_del_timer_sync(struct timer_list *timer);
diff --git a/kernel/time/timer.c b/kernel/time/timer.c
index 47165b16380a..3fd0b13c0b74 100644
--- a/kernel/time/timer.c
+++ b/kernel/time/timer.c
@@ -1293,21 +1293,21 @@ void add_timer(struct timer_list *timer)
 EXPORT_SYMBOL(add_timer);
 
 /**
  * add_timer_local() - Start a timer on the local CPU
  * @timer:	The timer to be started
  *
  * Same as add_timer() except that the timer flag TIMER_PINNED is set.
  *
  * See add_timer() for further details.
  */
-void add_timer_local(struct timer_list *timer)
+void timer_add_local(struct timer_list *timer)
 {
 	if (WARN_ON_ONCE(timer_pending(timer)))
 		return;
 	timer->flags |= TIMER_PINNED;
 	__mod_timer(timer, timer->expires, MOD_TIMER_NOTPENDING);
 }
-EXPORT_SYMBOL(add_timer_local);
+EXPORT_SYMBOL(timer_add_local);
 
 /**
  * timer_add_global() - Start a timer without TIMER_PINNED flag set
@@ -1293,21 +1293,21 @@ void add_timer(struct timer_list *timer)
 
 /**
- * add_timer_local() - Start a timer on the local CPU
+ * timer_add_local() - Start a timer on the local CPU
  * @timer:	The timer to be started
  *
-- 
2.45.2


  parent reply	other threads:[~2025-04-14 10:23 UTC|newest]

Thread overview: 30+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-04-14 10:22 [PATCH 00/17] timers: Complete the timer_*() API renames Ingo Molnar
2025-04-14 10:22 ` [PATCH 01/17] rust: Rename timer_container_of() to hrtimer_container_of() Ingo Molnar
2025-04-14 10:22 ` [PATCH 02/17] scsi: bfa: Rename 'timer_mod' to 'timer_module' Ingo Molnar
2025-04-14 10:59   ` Thomas Weißschuh
2025-04-14 11:21     ` [PATCH -v2 " Ingo Molnar
2025-04-14 16:57   ` [PATCH " Linus Torvalds
2025-04-16  5:28     ` Ingo Molnar
2025-04-16  5:37       ` Ingo Molnar
2025-04-14 18:02   ` Thomas Gleixner
2025-04-16  5:32     ` Ingo Molnar
2025-04-16  5:39       ` Ingo Molnar
2025-04-15 17:50   ` David Laight
2025-04-14 10:22 ` [PATCH 03/17] treewide, timers: Rename add_timer_global() => timer_add_global() Ingo Molnar
2025-04-14 10:22 ` Ingo Molnar [this message]
2025-04-14 10:22 ` [PATCH 05/17] treewide, timers: Rename from_timer() => timer_container_of() Ingo Molnar
2025-04-14 10:22 ` [PATCH 06/17] treewide, timers: Rename mod_timer_pending() => timer_mod_pending() Ingo Molnar
2025-04-14 10:22 ` [PATCH 07/17] treewide, timers: Rename try_to_del_timer_sync() => timer_delete_sync_try() Ingo Molnar
2025-04-14 10:22 ` [PATCH 08/17] treewide, timers: Rename add_timer() => timer_add() Ingo Molnar
2025-04-14 10:22 ` [PATCH 09/17] treewide, timers: Rename add_timer_on() => timer_add_on() Ingo Molnar
2025-04-14 10:22 ` [PATCH 10/17] treewide, timers: Rename mod_timer() => timer_mod() Ingo Molnar
2025-04-14 10:22 ` [PATCH 11/17] treewide, timers: Rename destroy_timer_on_stack() => timer_destroy_on_stack() Ingo Molnar
2025-04-14 10:22 ` [PATCH 12/17] treewide, timers: Rename init_timer_key() => timer_init_key() Ingo Molnar
2025-04-14 10:22 ` [PATCH 13/17] treewide, timers: Rename init_timer_on_stack_key() => timer_init_on_stack_key() Ingo Molnar
2025-04-14 10:22 ` [PATCH 14/17] treewide, timers: Rename __init_timer() => __timer_init() Ingo Molnar
2025-04-14 10:22 ` [PATCH 15/17] treewide, timers: Rename __init_timer_on_stack() => __timer_init_on_stack() Ingo Molnar
2025-04-14 10:22 ` [PATCH 16/17] treewide, timers: Rename NEXT_TIMER_MAX_DELTA => TIMER_NEXT_MAX_DELTA Ingo Molnar
2025-04-14 10:22 ` [PATCH 17/17] treewide, timers: Rename init_timers() => timers_init() Ingo Molnar
2025-04-14 10:35 ` [PATCH 00/17] timers: Complete the timer_*() API renames Ingo Molnar
2025-04-14 18:34   ` Thomas Gleixner
2025-04-16  9:04     ` Ingo Molnar

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20250414102301.332225-5-mingo@kernel.org \
    --to=mingo@kernel.org \
    --cc=frederic@kernel.org \
    --cc=hpa@zytor.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=peterz@infradead.org \
    --cc=tglx@linutronix.de \
    --cc=torvalds@linux-foundation.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox